@@ -43,6 +43,9 @@ def register(excelFile: "Excel file containing the component data",
         for i, k in enumerate(r.keys()):
             if k == "serialNumber":
                 JSON["serialNumber"] = r[k]
+            elif k == "alternativeIdentifier":
+                JSON["alternativeIdentifier"] = r[k]
+                JSON["serialNumber"] = None
             else:
                 Properties[k] = r[k]
         JSON['properties'] = Properties
