@@ -24,9 +24,12 @@ def authenticate():
             'project': 'P', 'pageInfo': {'pageSize': 32}})
         logger.info("Authentification successful")
     except itkdb.exceptions.ResponseException as e:
+        logger.error(e)
         logger.error("Wrong or missing login credentials")
         logger.info(
             "Set environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2")
+    except Exception as e:
+        logger.error(e)
 
 
 @argh.arg('-v', '--value', nargs='+', type=str)
@@ -66,7 +69,8 @@ def lookup(project: "ATLAS Project" = 'S',
                 print(json.dumps(results[k], indent=1))
         if returnResults or __name__ != '__main__':
             return results
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
@@ -98,7 +102,8 @@ def attach(file: "Path of the file to upload",
         client.post('createComponentAttachment',
                     data=data, files=attachment)
         logger.info(f"Attached file {file} to {component}")
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
@@ -120,7 +125,8 @@ def register(component: "Component to register (path to .json file or dict)"):
         client = itkdb.Client()
         client.post('registerComponent', json=component)
         logger.info(f"Registered new component")
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error(
             f"Unable to register component in the DB, is the format correct?")
 
@@ -144,7 +150,8 @@ def tests(componentType: "Type of component" = "BT",
                     print("  ", p['code'], ":", p['name'])
         if returnResults or __name__ != '__main__':
             return result
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
@@ -187,7 +194,8 @@ def stage(lookupValue: "Value to look up (must be unique in the DB!)",
     try:
         client.post('setComponentStage', data=data)
         logger.info(f"Set stage to {stage}")
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error(
             f"DB error, is {stage} a valid stage for {componentType}?")
 
@@ -244,7 +252,8 @@ def upload(result: "Results from the test (path to .json file or dict)"):
         client.post('uploadTestRunResults', json=result)
         logger.info(
             f"Uploaded {result['testType']} results for {result['component']} to the DB")
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error(f"Unable to upload result to DB, is the format correct?")
 
 
@@ -266,7 +275,8 @@ def testruns(cid: "Component ID",
                 print(json.dumps(results[k], indent=1))
         if returnResults or __name__ != '__main__':
             return results
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
@@ -298,7 +308,8 @@ def testfile(file: "Path of the file to upload",
         client.post('createTestRunAttachment',
                     data=data, files=attachment)
         logger.info(f"Attached file {file} to {testrun}")
-    except:
+    except Exception as e:
+        logger.error(e)
         logger.error("Error while trying to get connection to DB")
         logger.info(
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
